==> flink-1.15.0-src.tgz: flink-1.15.0/flink-libraries/flink-gelly-scala/src/main/scala/org/apache/flink/graph/scala/NeighborsFunctionWithVertexValue.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.graph.scala

import java.lang

import org.apache.flink.api.java.tuple.Tuple2
import org.apache.flink.graph.{Edge, Vertex}
import org.apache.flink.util.Collector


abstract class NeighborsFunctionWithVertexValue[K, VV, EV, T] extends org.apache.flink.graph
.NeighborsFunctionWithVertexValue[K, VV, EV, T] {

  def iterateNeighbors(vertex: Vertex[K, VV], neighbors: Iterable[(Edge[K, EV], Vertex[K, VV])
    ], out: Collector[T]): Unit

  override def iterateNeighbors(vertex: Vertex[K, VV], neighbors: lang.Iterable[Tuple2[Edge[K,
    EV], Vertex[K, VV]]], out: Collector[T]): Unit = {
    val scalaIterable = scala.collection.JavaConversions.iterableAsScalaIterable(neighbors)
      .map(jtuple => (jtuple.f0, jtuple.f1))
    iterateNeighbors(vertex, scalaIterable, out)
  }
}

==> flink-1.16.2-src.tgz: flink-1.16.2/flink-libraries/flink-gelly-scala/src/main/scala/org/apache/flink/graph/scala/NeighborsFunctionWithVertexValue.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.graph.scala

import org.apache.flink.api.java.tuple.Tuple2
import org.apache.flink.graph.{Edge, Vertex}
import org.apache.flink.util.Collector

import java.lang

abstract class NeighborsFunctionWithVertexValue[K, VV, EV, T]
  extends org.apache.flink.graph.NeighborsFunctionWithVertexValue[K, VV, EV, T] {

  def iterateNeighbors(
      vertex: Vertex[K, VV],
      neighbors: Iterable[(Edge[K, EV], Vertex[K, VV])],
      out: Collector[T]): Unit

  override def iterateNeighbors(
      vertex: Vertex[K, VV],
      neighbors: lang.Iterable[Tuple2[Edge[K, EV], Vertex[K, VV]]],
      out: Collector[T]): Unit = {
    val scalaIterable = scala.collection.JavaConversions
      .iterableAsScalaIterable(neighbors)
      .map(jtuple => (jtuple.f0, jtuple.f1))
    iterateNeighbors(vertex, scalaIterable, out)
  }
}
